#!/bin/sh

JOB_QUEUE="QUEUED_FILES/rescue2_jobs.queue"
TMP_QUEUE="QUEUED_FILES/tmp.queue"
RESCUE2="./rescue2_static"
BMRB_STATS="./BMRB_stats_static"
BMRB_DIR="/serv/DATABASE/BMRB/"

################################################################################
# Main loop on jobs
#
while test -s "$JOB_QUEUE" && test -z "`ps auwx | grep $RESCUE2 | grep -v grep`"; do

EMAIL="`head -1 $JOB_QUEUE | cut -d ' ' -f 1`"
FILE="`head -1 $JOB_QUEUE | cut -d ' ' -f 2`"
EXP="`head -1 $JOB_QUEUE | cut -d ' ' -f 3`"
BASE="`echo $FILE | sed 's,.sps,,' | sed 's,QUEUED_FILES/,,'`"
RES_FILE="RESULTS/${BASE}.res"
ERR_FILE="RESULTS/${BASE}.err"
EXP_FILE="RESULTS/${BASE}.exp"
NUC_FILE="RESULTS/${BASE}.nuc"

################################################################################
# Translate user NMR experiments to a set of nuclei
#
echo "$EXP" | tr ',' '\n' > "$EXP_FILE"
\rm -f "$NUC_FILE"
for exp in `cat $EXP_FILE`; do
  grep "^${exp}:" NMR_experiments.txt | cut -d ':' -f 2 | tr '\n' '|' >> "$NUC_FILE"
done
size=`cat $NUC_FILE | wc -c`
size=`echo "$size - 1" | bc`
pattern=`cat $NUC_FILE | cut -c 1-$size`
#echo "pattern = $pattern" > RESULTS/junk.tmp
size=`cat $NUC_FILE | tr '|' '\n' | sed s," ",, | cut -d ' ' -f 1 | sort | uniq | tr '\n' '_' | wc -c`
size=`echo "$size - 1" | bc`
nuclei=`cat $NUC_FILE | tr '|' '\n' | sed s," ",, | cut -d ' ' -f 1 | sort | uniq | tr '\n' '_' | cut -c 1-$size`
#echo "nuclei = $nuclei" >> RESULTS/junk.tmp
grep -E "$pattern" cs_all.in > RESULTS/cs.tmp
\mv -f RESULTS/cs.tmp "$NUC_FILE"

################################################################################
# Compute statistics (if necessary)
#
STAT_FILE="MODELS/BMRB_${nuclei}_stats.out"
if test ! -f $STAT_FILE; then
  $BMRB_STATS -bd "$BMRB_DIR" -i "$NUC_FILE" -o "$STAT_FILE" < BMRB_selected_sequences.txt 2> "$ERR_FILE"
fi

################################################################################
# Run RESCUE2
#
$RESCUE2 -cspd -af "$NUC_FILE" -sf "$STAT_FILE" < "$FILE" > "$RES_FILE" 2> "$ERR_FILE"

################################################################################
# Remove job from the queue
#
\mv -f "$JOB_QUEUE" "$TMP_QUEUE"
./rcat 1 < "$TMP_QUEUE" > "$JOB_QUEUE"
chmod g+w "$JOB_QUEUE" "$TMP_QUEUE"

################################################################################
# Send an email
#
mail -s "RESCUE2 results" $EMAIL<<EOMAIL
RESCUE2 prediction results for your spin systems:

`cat "$RES_FILE"`

--
T. Malliavin & A. Marin
EOMAIL
done # end of main loop on jobs
